----------
RPC Server
----------

.. automodule:: oslo_messaging.rpc.server

.. currentmodule:: oslo_messaging

.. autofunction:: get_rpc_server

.. autoclass:: RPCAccessPolicyBase

.. autoclass:: LegacyRPCAccessPolicy

.. autoclass:: DefaultRPCAccessPolicy

.. autoclass:: ExplicitRPCAccessPolicy

.. autoclass:: RPCDispatcher

.. autoclass:: MessageHandlingServer
   :members:

.. autofunction:: expected_exceptions

.. autofunction:: expose

.. autoexception:: ExpectedException
